@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMPORTADDRESSBOOKJOBINTERFACE_H
-#define IMPORTADDRESSBOOKJOBINTERFACE_H
+#pragma once
 
 #include "abstractimportexportjob.h"
 #include "pimdataexportercore_private_export.h"
@@ -35,4 +34,3 @@ private:
     Q_REQUIRED_RESULT QString installConfigLocation() const;
 };
 
-#endif // IMPORTADDRESSBOOKJOBINTERFACE_H
